/* Online image */
.online { background-image: url("./icon_user_online.gif"); }

.imageset.icon_user_online {
	background-image: url("./icon_user_online.gif");
	padding-left: 58px;
	padding-top: 58px;
}
